==> kget_22.12.3.orig.tar.xz: kget-22.12.3/desktop/org.kde.kget.desktop.cmake <==
# KDE Config File
[Desktop Entry]
Type=Application
Exec=kget -qwindowtitle %c %U
Icon=kget
Terminal=false
MimeType=@SUPPORTED_KGET_MIMETYPES@
Name=KGet
Name[ar]=كجت
Name[be]=KGet
Name[bg]=KGet
Name[bn]=কে-গেট
Name[br]=KGet
Name[bs]=KGet
Name[ca]=KGet
Name[ca@valencia]=KGet
Name[cs]=KGet
Name[cy]=KNôl
Name[da]=KGet
Name[de]=KGet
Name[el]=KGet
Name[en_GB]=KGet
Name[eo]=KGet
Name[es]=KGet
Name[et]=KGet
Name[eu]=KGet
Name[fi]=KGet
Name[fr]=KGet
Name[ga]=KGet
Name[gl]=KGet
Name[he]=KGet
Name[hi]=के-गेट
Name[hne]=के-गेट
Name[hr]=KGet
Name[hu]=KGet
Name[ia]=KGet
Name[id]=KGet
Name[is]=KGet
Name[it]=KGet
Name[ja]=KGet
Name[ka]=KGet
Name[kk]=KGet
Name[km]=KGet
Name[ko]=KGet
Name[lt]=KGet
Name[lv]=KGet
Name[mk]=KGet
Name[ml]=കെഗെറ്റ്
Name[mr]=के-गेट
Name[ms]=KGet
Name[nb]=KGet
Name[nds]=KGet
Name[ne]=केडीई गेट
Name[nl]=KGet
Name[nn]=KGet
Name[pa]=ਕੇ-ਗੈੱਟ
Name[pl]=KGet
Name[pt]=KGet
Name[pt_BR]=KGet
Name[ro]=KGet
Name[ru]=KGet
Name[se]=KGet
Name[si]=KGet
Name[sk]=KGet
Name[sl]=KGet
Name[sq]=KGet
Name[sr]=К‑гет
Name[sr@ijekavian]=К‑гет
Name[sr@ijekavianlatin]=KGet
Name[sr@latin]=KGet
Name[sv]=Kget
Name[ta]=கேகெட்
Name[tg]=KGet
Name[th]=ดาวน์โหลด-K
Name[tr]=KGet
Name[ug]=KGet
Name[uk]=KGet
Name[vi]=KGet
Name[wa]=KGet
Name[xh]=KGet
Name[x-test]=xxKGetxx
Name[zh_CN]=KGet
Name[zh_HK]=KGet
Name[zh_TW]=檔案傳輸_KGet
GenericName=Download Manager
GenericName[ar]=مدير التّنزيل
GenericName[be]=Праграма сцягвання файлаў
GenericName[bg]=Изтегляне на файлове
GenericName[bn]=ডাউনলোড ম্যানেজার
GenericName[br]=Merour enkargañ
GenericName[bs]=Menadžer preuzimanja
GenericName[ca]=Gestor de baixades
GenericName[ca@valencia]=Gestor de baixades
GenericName[cs]=Správce stahování
GenericName[cy]=Rheolydd Lawrlwytho
GenericName[da]=Håndtering af download
GenericName[de]=Download-Verwaltung
GenericName[el]=Διαχειριστής λήψεων αρχείων
GenericName[en_GB]=Download Manager
GenericName[eo]=Elŝuta administrilo
GenericName[es]=Gestor de descargas
GenericName[et]=Allalaadimiste haldur
GenericName[eu]=Deskarga-kudeatzailea
GenericName[fa]=مدیر بارگیری
GenericName[fi]=Tiedostonlataaja
GenericName[fr]=Gestionnaire de téléchargements
GenericName[ga]=Bainisteoir Íosluchtaithe
GenericName[gl]=Xestor de descargas
GenericName[he]=מנהל הורדות
GenericName[hi]=डाउनलोड प्रबंधक
GenericName[hne]=डाउनलोड  प्रबंधक
GenericName[hr]=Upravitelj preuzimanja
GenericName[hu]=Letöltéskezelő
GenericName[ia]=Gerente de discargamento
GenericName[id]=Manajer Unduhan
GenericName[is]=Niðurhalsstjóri
GenericName[it]=Gestore degli scaricamenti
GenericName[ja]=ダウンロードマネージャ
GenericName[ka]=გადმოწერების მმართველი
GenericName[kk]=Жүктеп алу менеджері
GenericName[km]=កម្មវិធី​គ្រប់គ្រង​ការ​ទាញយក
GenericName[ko]=다운로드 관리자
GenericName[lt]=Siuntimų valdymas
GenericName[lv]=Lejupielāžu pārvaldnieks
GenericName[mk]=Менаџер за симнувања
GenericName[ml]=ഇറക്കിവെക്കല്‍ കാര്യസ്ഥന്‍
GenericName[mr]=डाउनलोड व्यवस्थापक
GenericName[nb]=Nedlastingsbehandler
GenericName[nds]=Daalladenpleger
GenericName[ne]=डाउनलोड प्रबन्धक
GenericName[nl]=Downloadbeheerder
GenericName[nn]=Nedlastingshandsamar
GenericName[pa]=ਡਾਊਨਲੋਡ ਮੈਨੇਜਰ
GenericName[pl]=Zarządzanie pobieraniem
GenericName[pt]=Gestor de Transferências
GenericName[pt_BR]=Gerenciador de downloads
GenericName[ro]=Administrator descărcări
GenericName[ru]=Диспетчер загрузок
GenericName[si]=බාගැනීම් කළමනාකරු
GenericName[sk]=Správca preberaní
GenericName[sl]=Upravljalnik prenosov
GenericName[sq]=Organizuesi i Shkarkimeve
GenericName[sr]=Менаџер преузимања
GenericName[sr@ijekavian]=Менаџер преузимања
GenericName[sr@ijekavianlatin]=Menadžer preuzimanja
GenericName[sr@latin]=Menadžer preuzimanja
GenericName[sv]=Nerladdningshanterare
GenericName[ta]=பதிவிறக்க மேலாளர்
GenericName[tg]=Мудири Боркунӣ
GenericName[th]=เครื่องมือจัดการการดาวน์โหลด
GenericName[tr]=İndirme Yöneticisi
GenericName[ug]=چۈشۈرۈش باشقۇرغۇسى
GenericName[uk]=Керування отриманнями
GenericName[uz]=Yozib olish boshqaruvchisi
GenericName[uz@cyrillic]=Ёзиб олиш бошқарувчиси
GenericName[vi]=Trình quản lí việc tải tệp
GenericName[wa]=Manaedjeu d' aberwetaedje
GenericName[x-test]=xxDownload Managerxx
GenericName[zh_CN]=下载管理器
GenericName[zh_HK]=下載管理員
GenericName[zh_TW]=下載管理員
Comment=KGet is a versatile and user-friendly download manager
Comment[ar]=كجت هو مدير تنزيل متعدد الاستخدامات وسهل الاستخدام
Comment[bg]=KGet е гъвкава и потребителска ориентирана програма за управления на изтегляния
Comment[ca]=El KGet és un gestor de baixades versàtil i fàcil d'emprar
Comment[ca@valencia]=KGet és un gestor de baixades versàtil i fàcil d'emprar
Comment[cs]=KGet je všestranný a jednoduše použitelný správce stahování
Comment[da]=KGET er en alsidig og brugervenlig downloadhåndtering
Comment[de]=KGet ist ein vielseitiges und einfach zu benutzendes Download-Verwaltungsprogramm
Comment[el]=Το KGet είναι ένας ευέλικτος και εύκολος στη χρήση διαχειριστής λήψεων αρχείων
Comment[en_GB]=KGet is a versatile and user-friendly download manager
Comment[es]=KGet es un versátil y amigable gestor de descargas
Comment[eu]=KGet gaitasun anitzeko zama-jaisteko kudeatzaile erabilerraza da
Comment[fi]=KGet on monipuolinen ja helppokäyttöinen latauksenhallinta
Comment[fr]=KGet est un gestionnaire de téléchargement intuitif et polyvalent.
Comment[ia]=KGet es un gerente per discargar versatile e amical
Comment[id]=KGet adalah download manager yang serbaguna dan mudah digunakan
Comment[it]=KGet è un gestore di scaricamenti versatile e facile da utilizzare
Comment[ka]=KGet გაფართოებადი და მეგობრული გადმოწერების მმართველია
Comment[ko]=KGet은 기능이 다양하고 사용하기 편리한 다운로드 관리자입니다
Comment[nl]=KGet is een veelzijdige en gebruikersvriendelijke downloadbeheerder
Comment[pl]=KGet jest wszechstronnym i przyjaznym użytkownikowi programem do zarządzania pobieraniem
Comment[pt]=O KGet é um gestor de transferências de ficheiros simples e versátil de usar
Comment[pt_BR]=O KGet é um gerenciador de downloads versátil e amigável
Comment[ru]=KGet — это гибкий и простой в использовании диспетчер загрузок
Comment[sk]=KGet je univerzálny a ľahko použiteľný správca sťahovania
Comment[sl]=KGet je vsestranski in uporabniku prijazen upravitelj prenosov
Comment[sv]=Kget är en mångsidig och lättanvänd nerladdningshanterare
Comment[tr]=KGet, çok kapsamlı ve kullanıcı dostu bir indirme yöneticisidir
Comment[uk]=KGet — гнучка і зручна програма для отримання даних з мережі
Comment[x-test]=xxKGet is a versatile and user-friendly download managerxx
Comment[zh_CN]=KGet 是一个功能多样且用户友好的下载管理器
Categories=Qt;KDE;Network;FileTransfer;
X-DBUS-ServiceType=Unique
X-DocPath=kget/index.html
X-DBUS-ServiceName=org.kde.kget

==> kget-23.04.0.tar.xz: kget-23.04.0/desktop/org.kde.kget.desktop.cmake <==
# KDE Config File
[Desktop Entry]
Type=Application
Exec=kget -qwindowtitle %c %U
Icon=kget
Terminal=false
MimeType=@SUPPORTED_KGET_MIMETYPES@
Name=KGet
Name[ar]=كجت
Name[be]=KGet
Name[bg]=KGet
Name[bn]=কে-গেট
Name[br]=KGet
Name[bs]=KGet
Name[ca]=KGet
Name[ca@valencia]=KGet
Name[cs]=KGet
Name[cy]=KNôl
Name[da]=KGet
Name[de]=KGet
Name[el]=KGet
Name[en_GB]=KGet
Name[eo]=KGet
Name[es]=KGet
Name[et]=KGet
Name[eu]=KGet
Name[fi]=KGet
Name[fr]=KGet
Name[ga]=KGet
Name[gl]=KGet
Name[he]=KGet
Name[hi]=के-गेट
Name[hne]=के-गेट
Name[hr]=KGet
Name[hu]=KGet
Name[ia]=KGet
Name[id]=KGet
Name[is]=KGet
Name[it]=KGet
Name[ja]=KGet
Name[ka]=KGet
Name[kk]=KGet
Name[km]=KGet
Name[ko]=KGet
Name[lt]=KGet
Name[lv]=KGet
Name[mk]=KGet
Name[ml]=കെഗെറ്റ്
Name[mr]=के-गेट
Name[ms]=KGet
Name[nb]=KGet
Name[nds]=KGet
Name[ne]=केडीई गेट
Name[nl]=KGet
Name[nn]=KGet
Name[pa]=ਕੇ-ਗੈੱਟ
Name[pl]=KGet
Name[pt]=KGet
Name[pt_BR]=KGet
Name[ro]=KGet
Name[ru]=KGet
Name[se]=KGet
Name[si]=KGet
Name[sk]=KGet
Name[sl]=KGet
Name[sq]=KGet
Name[sr]=К‑гет
Name[sr@ijekavian]=К‑гет
Name[sr@ijekavianlatin]=KGet
Name[sr@latin]=KGet
Name[sv]=Kget
Name[ta]=கேகெட்
Name[tg]=KGet
Name[th]=ดาวน์โหลด-K
Name[tr]=K İndir
Name[ug]=KGet
Name[uk]=KGet
Name[vi]=KGet
Name[wa]=KGet
Name[xh]=KGet
Name[x-test]=xxKGetxx
Name[zh_CN]=KGet
Name[zh_HK]=KGet
Name[zh_TW]=檔案傳輸_KGet
GenericName=Download Manager
GenericName[ar]=مدير التّنزيل
GenericName[be]=Праграма сцягвання файлаў
GenericName[bg]=Изтегляне на файлове
GenericName[bn]=ডাউনলোড ম্যানেজার
GenericName[br]=Merour enkargañ
GenericName[bs]=Menadžer preuzimanja
GenericName[ca]=Gestor de baixades
GenericName[ca@valencia]=Gestor de baixades
GenericName[cs]=Správce stahování
GenericName[cy]=Rheolydd Lawrlwytho
GenericName[da]=Håndtering af download
GenericName[de]=Download-Verwaltung
GenericName[el]=Διαχειριστής λήψεων αρχείων
GenericName[en_GB]=Download Manager
GenericName[eo]=Elŝuta administrilo
GenericName[es]=Gestor de descargas
GenericName[et]=Allalaadimiste haldur
GenericName[eu]=Deskarga-kudeatzailea
GenericName[fa]=مدیر بارگیری
GenericName[fi]=Tiedostonlataaja
GenericName[fr]=Gestionnaire de téléchargements
GenericName[ga]=Bainisteoir Íosluchtaithe
GenericName[gl]=Xestor de descargas
GenericName[he]=מנהל הורדות
GenericName[hi]=डाउनलोड प्रबंधक
GenericName[hne]=डाउनलोड  प्रबंधक
GenericName[hr]=Upravitelj preuzimanja
GenericName[hu]=Letöltéskezelő
GenericName[ia]=Gerente de discargamento
GenericName[id]=Manajer Unduhan
GenericName[is]=Niðurhalsstjóri
GenericName[it]=Gestore degli scaricamenti
GenericName[ja]=ダウンロードマネージャ
GenericName[ka]=გადმოწერების მმართველი
GenericName[kk]=Жүктеп алу менеджері
GenericName[km]=កម្មវិធី​គ្រប់គ្រង​ការ​ទាញយក
GenericName[ko]=다운로드 관리자
GenericName[lt]=Siuntimų valdymas
GenericName[lv]=Lejupielāžu pārvaldnieks
GenericName[mk]=Менаџер за симнувања
GenericName[ml]=ഇറക്കിവെക്കല്‍ കാര്യസ്ഥന്‍
GenericName[mr]=डाउनलोड व्यवस्थापक
GenericName[nb]=Nedlastingsbehandler
GenericName[nds]=Daalladenpleger
GenericName[ne]=डाउनलोड प्रबन्धक
GenericName[nl]=Downloadbeheerder
GenericName[nn]=Nedlastingshandsamar
GenericName[pa]=ਡਾਊਨਲੋਡ ਮੈਨੇਜਰ
GenericName[pl]=Zarządzanie pobieraniem
GenericName[pt]=Gestor de Transferências
GenericName[pt_BR]=Gerenciador de downloads
GenericName[ro]=Administrator descărcări
GenericName[ru]=Диспетчер загрузок
GenericName[si]=බාගැනීම් කළමනාකරු
GenericName[sk]=Správca preberaní
GenericName[sl]=Upravljalnik prenosov
GenericName[sq]=Organizuesi i Shkarkimeve
GenericName[sr]=Менаџер преузимања
GenericName[sr@ijekavian]=Менаџер преузимања
GenericName[sr@ijekavianlatin]=Menadžer preuzimanja
GenericName[sr@latin]=Menadžer preuzimanja
GenericName[sv]=Nerladdningshanterare
GenericName[ta]=பதிவிறக்க மேலாளர்
GenericName[tg]=Мудири Боркунӣ
GenericName[th]=เครื่องมือจัดการการดาวน์โหลด
GenericName[tr]=İndirme Yöneticisi
GenericName[ug]=چۈشۈرۈش باشقۇرغۇسى
GenericName[uk]=Керування отриманнями
GenericName[uz]=Yozib olish boshqaruvchisi
GenericName[uz@cyrillic]=Ёзиб олиш бошқарувчиси
GenericName[vi]=Trình quản lí việc tải tệp
GenericName[wa]=Manaedjeu d' aberwetaedje
GenericName[x-test]=xxDownload Managerxx
GenericName[zh_CN]=下载管理器
GenericName[zh_HK]=下載管理員
GenericName[zh_TW]=下載管理員
Comment=KGet is a versatile and user-friendly download manager
Comment[ar]=كجت هو مدير تنزيل متعدد الاستخدامات وسهل الاستخدام
Comment[bg]=KGet е гъвкава и потребителска ориентирана програма за управления на изтегляния
Comment[ca]=El KGet és un gestor de baixades versàtil i fàcil d'emprar
Comment[ca@valencia]=KGet és un gestor de baixades versàtil i fàcil d'emprar
Comment[cs]=KGet je všestranný a jednoduše použitelný správce stahování
Comment[da]=KGET er en alsidig og brugervenlig downloadhåndtering
Comment[de]=KGet ist ein vielseitiges und einfach zu benutzendes Download-Verwaltungsprogramm
Comment[el]=Το KGet είναι ένας ευέλικτος και εύκολος στη χρήση διαχειριστής λήψεων αρχείων
Comment[en_GB]=KGet is a versatile and user-friendly download manager
Comment[es]=KGet es un versátil y amigable gestor de descargas
Comment[eu]=KGet gaitasun anitzeko zama-jaisteko kudeatzaile erabilerraza da
Comment[fi]=KGet on monipuolinen ja helppokäyttöinen latauksenhallinta
Comment[fr]=KGet est un gestionnaire de téléchargement intuitif et polyvalent.
Comment[ia]=KGet es un gerente per discargar versatile e amical
Comment[id]=KGet adalah download manager yang serbaguna dan mudah digunakan
Comment[it]=KGet è un gestore di scaricamenti versatile e facile da utilizzare
Comment[ka]=KGet გაფართოებადი და მეგობრული გადმოწერების მმართველია
Comment[ko]=KGet은 기능이 다양하고 사용하기 편리한 다운로드 관리자입니다
Comment[nl]=KGet is een veelzijdige en gebruikersvriendelijke downloadbeheerder
Comment[pl]=KGet jest wszechstronnym i przyjaznym użytkownikowi programem do zarządzania pobieraniem
Comment[pt]=O KGet é um gestor de transferências de ficheiros simples e versátil de usar
Comment[pt_BR]=O KGet é um gerenciador de downloads versátil e amigável
Comment[ru]=KGet — это гибкий и простой в использовании диспетчер загрузок
Comment[sk]=KGet je univerzálny a ľahko použiteľný správca sťahovania
Comment[sl]=KGet je vsestranski in uporabniku prijazen upravitelj prenosov
Comment[sv]=Kget är en mångsidig och lättanvänd nerladdningshanterare
Comment[tr]=K İndir, çok kapsamlı ve kullanıcı dostu bir indirme yöneticisidir
Comment[uk]=KGet — гнучка і зручна програма для отримання даних з мережі
Comment[x-test]=xxKGet is a versatile and user-friendly download managerxx
Comment[zh_CN]=KGet 是一个功能多样且用户友好的下载管理器
Categories=Qt;KDE;Network;FileTransfer;
X-DBUS-ServiceType=Unique
X-DocPath=kget/index.html
X-DBUS-ServiceName=org.kde.kget
